@@ -14,7 +14,8 @@
 # limitations under the License.
 
 """
-This module contains a common interface to symbolic operations in Sympy and Symengine respectively.
+This module contains a common interface to symbolic operations in Sympy and Symengine
+respectively.
 All symbolic operations in the optlang codebase should use these functions.
 """
 
@@ -46,9 +47,6 @@ else:  # pragma: no cover
 
 
 if USE_SYMENGINE:  # pragma: no cover # noqa: C901
-    import operator
-    from six.moves import reduce
-
     optlang._USING_SYMENGINE = True
 
     Integer = symengine.Integer
@@ -59,12 +57,15 @@ if USE_SYMENGINE:  # pragma: no cover # noqa: C901
     One = Real(1)
     NegativeOne = Real(-1)
     sympify = symengine.sympify
+    Expr = symengine.Expr
 
     Add = symengine.Add
     Mul = symengine.Mul
     Pow = symengine.Pow
 
     class Symbol(symengine_Symbol):
+        """A generic symbol used in expressions."""
+
         def __new__(cls, name, *args, **kwargs):
             if not isinstance(name, six.string_types):
                 raise TypeError("name should be a string, not %s" % repr(type(name)))
@@ -100,9 +101,6 @@ if USE_SYMENGINE:  # pragma: no cover # noqa: C901
 
 else:  # Use sympy
     import sympy
-    from sympy.core.assumptions import _assume_rules
-    from sympy.core.facts import FactKB
-    from sympy.core.expr import Expr
 
     optlang._USING_SYMENGINE = False
 
@@ -114,24 +112,20 @@ else:  # Use sympy
     One = Real(1)
     NegativeOne = Real(-1)
     sympify = sympy.sympify
+    Expr = sympy.core.expr.Expr
 
     Add = sympy.Add
     Mul = sympy.Mul
     Pow = sympy.Pow
 
-    class Symbol(sympy.Symbol):
-        def __new__(cls, name, **kwargs):
+    class Symbol(sympy.core.Dummy):
+        """A generic symbol used in expressions."""
+
+        def __new__(cls, name, *args, **kwargs):
             if not isinstance(name, six.string_types):
                 raise TypeError("name should be a string, not %s" % repr(type(name)))
 
-            obj = sympy.Symbol.__new__(cls, str(uuid.uuid1()))
-
-            obj.name = name
-            obj._assumptions = FactKB(_assume_rules)
-            obj._assumptions._tell('commutative', True)
-            obj._assumptions._tell('uuid', uuid.uuid1())
-
-            return obj
+            return sympy.core.Dummy.__new__(cls, name)
 
         def __init__(self, *args, **kwargs):
             super(Symbol, self).__init__()
