@@ -16,18 +16,19 @@
 from __future__ import division
 
 import abc
+import copy
+import json
+import os
+import pickle
 import unittest
+from functools import partial
 
 import six
-from optlang import interface
-from optlang import symbolics
-import optlang
-import pickle
-import json
-import copy
-import os
 import sympy
-from functools import partial
+
+import optlang
+from optlang import interface, symbolics
+
 
 __test__ = False
 
@@ -634,15 +635,15 @@ class AbstractModelTestCase(unittest.TestCase):
         self.model.objective = self.interface.Objective(1. * v1 + 1. * v2)
         self.assertEqual(self.model.objective.direction, "max")
         self.assertEqual(
-            (self.model.objective.expression -
-             (1.0 * self.model.variables["R_PGK"] + 1.0 * self.model.variables["R_Biomass_Ecoli_core_w_GAM"])).expand(),
+            float((self.model.objective.expression -
+             (1.0 * self.model.variables["R_PGK"] + 1.0 * self.model.variables["R_Biomass_Ecoli_core_w_GAM"])).expand()),
             0.
         )
         self.model.objective = self.interface.Objective(v1 + v2)
         self.assertEqual(self.model.objective.direction, "max")
         self.assertEqual(
-            (self.model.objective.expression -
-             (1.0 * self.model.variables["R_PGK"] + 1.0 * self.model.variables["R_Biomass_Ecoli_core_w_GAM"])).expand(),
+            float((self.model.objective.expression -
+             (1.0 * self.model.variables["R_PGK"] + 1.0 * self.model.variables["R_Biomass_Ecoli_core_w_GAM"])).expand()),
             0.
         )
 
