@@ -1,9 +1,13 @@
 # Copyright (c) 2016 Novo Nordisk Foundation Center for Biosustainability, DTU.
 # See LICENSE for details.
 
+import os
 import pickle
+import pytest
+import sys
 import unittest
 
+
 try:  # noqa: C901
     import gurobipy
 except ImportError as e:
@@ -17,18 +21,15 @@ except ImportError as e:
 else:
 
     import copy
-
+    import os
+    import pickle
     import random
 
-    import os
-
-    import nose
-    import pickle
-
-    from optlang.gurobi_interface import Variable, Constraint, Model, Objective
     from gurobipy import GurobiError
-    from optlang.tests import abstract_test_cases
+
     from optlang import gurobi_interface
+    from optlang.gurobi_interface import Constraint, Model, Objective, Variable
+    from optlang.tests import abstract_test_cases
 
     random.seed(666)
     TESTMODELPATH = os.path.join(os.path.dirname(__file__), 'data/model.lp')
@@ -53,24 +54,18 @@ else:
             self.assertEqual(self.var.primal, None)
             model = Model(problem=gurobipy.read(TESTMODELPATH))
             model.optimize()
-            for i, j in zip([var.primal for var in model.variables],
-                            [0.8739215069684306, -16.023526143167608, 16.023526143167604, -14.71613956874283,
-                             14.71613956874283, 4.959984944574658, 4.959984944574657, 4.959984944574658,
-                             3.1162689467973905e-29, 2.926716099010601e-29, 0.0, 0.0, -6.112235045340358e-30,
-                             -5.6659435396316186e-30, 0.0, -4.922925402711085e-29, 0.0, 9.282532599166613, 0.0,
-                             6.00724957535033, 6.007249575350331, 6.00724957535033, -5.064375661482091,
-                             1.7581774441067828, 0.0, 7.477381962160285, 0.0, 0.22346172933182767, 45.514009774517454,
-                             8.39, 0.0, 6.007249575350331, 0.0, -4.541857463865631, 0.0, 5.064375661482091, 0.0, 0.0,
-                             2.504309470368734, 0.0, 0.0, -22.809833310204958, 22.809833310204958, 7.477381962160285,
-                             7.477381962160285, 1.1814980932459636, 1.496983757261567, -0.0, 0.0, 4.860861146496815,
-                             0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 5.064375661482091, 0.0, 5.064375661482091, 0.0, 0.0,
-                             1.496983757261567, 10.000000000000002, -10.0, 0.0, 0.0, 0.0, 0.0, 0.0, -29.175827135565804,
-                             43.598985311997524, 29.175827135565804, 0.0, 0.0, 0.0, -1.2332237321082153e-29,
-                             3.2148950476847613, 38.53460965051542, 5.064375661482091, 0.0, -1.2812714099825612e-29,
-                             -1.1331887079263237e-29, 17.530865429786694, 0.0, 0.0, 0.0, 4.765319193197458,
-                             -4.765319193197457, 21.79949265599876, -21.79949265599876, -3.2148950476847613, 0.0,
-                             -2.281503094067127, 2.6784818505075303, 0.0]):
-                self.assertAlmostEqual(i, j)
+            ref = dict([
+                ('R_Biomass_Ecoli_core_w_GAM', 0.8739215069684303),
+                ('R_PGK', -16.023526143282652),
+                ('R_GAPD', 16.023526143282652),
+                ('R_PGM', -14.716139568015933),
+                ('R_ENO', 14.716139568015933),
+                ('R_PGL', 4.959984944574658),
+                ('R_GND', 4.959984944574658),
+                ('R_G6PDH2r', 4.959984945133328)
+            ])
+            for vid in ref:
+                self.assertAlmostEqual(ref[vid], model.variables[vid].primal)
 
         def test_changing_variable_names_is_reflected_in_the_solver(self):
             model = Model(problem=gurobipy.read(TESTMODELPATH))
@@ -427,8 +422,9 @@ else:
                 0
             )
 
+        @pytest.mark.xfail(sys.platform == "win32", reason="buggy with windows clocks")
         def test_timeout(self):
-            self.model.configuration.timeout = 0
+            self.model.configuration.timeout = int(0)
             status = self.model.optimize()
             print(status)
             self.assertEqual(status, 'time_limit')
@@ -492,6 +488,7 @@ else:
                 self.assertAlmostEqual(self.x1.primal, 0.0)
                 self.assertGreaterEqual(self.x2.primal, 1.0)
 
+            @unittest.skipIf("CI" in os.environ, "Model too large for community edition.")
             def test_qp_convex(self):
                 model = Model(problem=gurobipy.read(CONVEX_QP_PATH))
                 self.assertEqual(len(model.variables), 651)
@@ -524,6 +521,3 @@ else:
                 objective = Objective(self.x1 ** 2 + self.x2 ** 2, direction="min")
                 self.model.objective = objective
                 self.assertEqual((self.model.objective.expression - (self.x1 ** 2 + self.x2 ** 2)).simplify(), 0)
-
-if __name__ == '__main__':
-    nose.runmodule()
